@@ -39,7 +39,7 @@ modified to better fit within TurboGears. Vince Spicer and Mathieu Bridon have
 contributed some additions and improvements such as cron-like tasks. Some fixes
 have been made to make it work on Python 2.6 (adaptations sched module changes).
 
-This version has been extracted from the Turbogears source repository
+This version has been extracted from the TurboGears source repository
 and slightly changed to be completely stand-alone again.
 
 This is open-source software, released under the MIT Software License:
@@ -410,8 +410,7 @@ class Scheduler(object):
     def rename(self, taskname, newname):
         """Rename a scheduled task."""
         if taskname and taskname in self.tasks:
-            task = self.tasks[taskname]
-            del self.tasks[taskname]
+            task = self.tasks.pop(taskname)
             task.name = newname
             self.tasks[newname] = task
 
